<?php
/**
 * TrueReview Theme Customizer
 */

// Loads custom control
require trailingslashit( get_template_directory() ) . 'inc/customizer/controls/custom-text.php';

// Loads the customizer settings
require trailingslashit( get_template_directory() ) . 'inc/customizer/featured-posts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/breaking.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/social.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/misc.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/layouts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/colors.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/ads-top.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/ads-header.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/ads-menu.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/ads-footer.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/ads-before-content.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/ads-after-content.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/ads-after-paragraph.php';

/**
 * Custom customizer functions.
 */
function truereview_customize_functions( $wp_customize ) {

	// Register new panel: Design
	$wp_customize->add_panel( 'truereview_design', array(
		'title'       => esc_html__( 'Design', 'truereview' ),
		'description' => esc_html__( 'This panel is used for customizing the design of your site.', 'truereview' ),
		'priority'    => 125,
	) );

	// Register new panel: Theme Options
	$wp_customize->add_panel( 'truereview_options', array(
		'title'       => esc_html__( 'Theme Options', 'truereview' ),
		'description' => esc_html__( 'This panel is used for customizing the TrueReview theme.', 'truereview' ),
		'priority'    => 130,
	) );

	// Register new panel: Advertisement
	$wp_customize->add_panel( 'truereview_ads', array(
		'title'       => esc_html__( 'Advertisement', 'truereview' ),
		'description' => esc_html__( 'This panel is an advertisement manager.', 'truereview' ),
		'priority'    => 135,
	) );

	// Live preview of Site Title
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

	// Enable selective refresh to the Site Title
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'            => '.site-title a',
			'settings'         => array( 'blogname' ),
			'render_callback'  => function() {
				return get_bloginfo( 'name', 'display' );
			}
		) );
	}

	// Move the Colors section.
	$wp_customize->get_section( 'colors' )->panel    = 'truereview_design';
	$wp_customize->get_section( 'colors' )->priority = 1;

	// Move the Theme Layout
	$wp_customize->get_section( 'layout' )->panel     = 'truereview_design';
	$wp_customize->get_section( 'layout' )->title     = esc_html__( 'Layouts', 'truereview' );
	$wp_customize->get_section( 'layout' )->priority  = 3;

	// Move the Background Image section.
	$wp_customize->get_section( 'background_image' )->panel    = 'truereview_design';
	$wp_customize->get_section( 'background_image' )->priority = 7;

	// Move the Static Front Page section.
	$wp_customize->get_section( 'static_front_page' )->panel    = 'truereview_design';
	$wp_customize->get_section( 'static_front_page' )->priority = 9;

	// Move the Additional CSS section.
	$wp_customize->get_section( 'custom_css' )->panel    = 'truereview_design';
	$wp_customize->get_section( 'custom_css' )->priority = 11;

	// Move background color to background image section.
	$wp_customize->get_section( 'background_image' )->title = esc_html__( 'Background', 'truereview' );
	$wp_customize->get_control( 'background_color' )->section = 'background_image';

}
add_action( 'customize_register', 'truereview_customize_functions', 99 );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function truereview_customize_preview_js() {
	wp_enqueue_script( 'truereview-customizer', get_template_directory_uri() . '/assets/js/customizer/customizer.js', array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'truereview_customize_preview_js' );

/**
 * Skins
 */
function truereview_customizer_skins() {

	// Predefined skins
	$skins = get_theme_mod( 'truereview-skins', 'default' );

	// Load skin stylesheet
	wp_enqueue_style( 'truereview-skin', trailingslashit( get_template_directory_uri() ) . 'assets/css/skins/' . $skins . '.css', array(), null );

}
add_action( 'wp_enqueue_scripts', 'truereview_customizer_skins' );

/**
 * Display theme documentation on customizer page.
 */
function truereview_documentation_link() {

	// Enqueue the script
	wp_enqueue_script( 'truereview-doc', get_template_directory_uri() . '/assets/js/customizer/doc.js', array(), '1.0.0', true );

	// Localize the script
	wp_localize_script( 'truereview-doc', 'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/truereview/' ),
			'prefixLabel' => esc_html__( 'Documentation', 'truereview' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'truereview_documentation_link' );

/**
 * Custom RSS feed url.
 */
function truereview_custom_rss_url( $output, $feed ) {

	// Get the custom rss feed url
	$url = get_theme_mod( 'truereview-custom-rss' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( ! empty( $url ) ) {
		$output = esc_url( $url );
	}

	return $output;
}
add_filter( 'feed_link', 'truereview_custom_rss_url', 10, 2 );

if ( ! function_exists( 'truereview_top_ads' ) ) :
/**
 * Prints the advertisement data set in customizer.
 *
 * @since  1.0.0
 */
function truereview_top_ads() {

	// Get the ads data set in customizer
	$img    = get_theme_mod( 'truereview-top-ads-image' );
	$url    = get_theme_mod( 'truereview-top-ads-url' );
	$custom = get_theme_mod( 'truereview-top-ads-custom' );

	// Display the data
	if ( $img || $url || $custom ) {
		echo '<div class="top-ads">';
			echo '<div class="container">';
				if ( $custom ) {
					echo stripslashes( $custom );
				} else {
					echo '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( wp_get_attachment_url( $img ) ) . '" alt="' . esc_html__( 'Advertisement', 'truereview' ) . '" /></a>';
				}
			echo '</div>';
		echo '</div>';
	}

}
endif;

if ( ! function_exists( 'truereview_header_ads' ) ) :
/**
 * Prints the advertisement data set in customizer.
 *
 * @since  1.0.0
 */
function truereview_header_ads() {

	// Get the ads data set in customizer
	$img    = get_theme_mod( 'truereview-header-ads-image' );
	$url    = get_theme_mod( 'truereview-header-ads-url' );
	$custom = get_theme_mod( 'truereview-header-ads-custom' );

	// Display the data
	if ( $img || $url || $custom ) {
		echo '<div class="header-ad">';
			if ( $custom ) {
				echo stripslashes( $custom );
			} else {
				echo '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( wp_get_attachment_url( $img ) ) . '" alt="' . esc_html__( 'Advertisement', 'truereview' ) . '" /></a>';
			}
		echo '</div>';
	}

}
endif;

if ( ! function_exists( 'truereview_after_menu_ads' ) ) :
/**
 * Prints the advertisement data set in customizer.
 *
 * @since  1.0.0
 */
function truereview_after_menu_ads() {

	// Get the ads data set in customizer
	$img    = get_theme_mod( 'truereview-after-menu-ads-image' );
	$url    = get_theme_mod( 'truereview-after-menu-ads-url' );
	$custom = get_theme_mod( 'truereview-after-menu-ads-custom' );

	// Display the data
	if ( $img || $url || $custom ) {
		echo '<div class="after-menu-ads">';
			echo '<div class="container">';
				if ( $custom ) {
					echo stripslashes( $custom );
				} else {
					echo '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( wp_get_attachment_url( $img ) ) . '" alt="' . esc_html__( 'Advertisement', 'truereview' ) . '" /></a>';
				}
			echo '</div>';
		echo '</div>';
	}

}
endif;

if ( ! function_exists( 'truereview_post_ads_before' ) ) :
/**
 * Single post advertisement.
 * Before content.
 *
 * @since  1.0.0
 */
function truereview_post_ads_before( $content ) {

	// Set up empty variable
	$ads = '';

	// Get the ads data set in customizer
	$img    = get_theme_mod( 'truereview-post-ads-image-before' );
	$url    = get_theme_mod( 'truereview-post-ads-url-before' );
	$custom = get_theme_mod( 'truereview-post-ads-custom-before' );
	$pos    = get_theme_mod( 'truereview-post-ads-position-before' );

	// Set up our ads.
	if ( $img || $url || $custom ) {
		$ads = '<div class="post-ads-before post-ads ' . esc_attr( $pos ) . '-position' . '">';
			if ( $custom ) {
				$ads .= stripslashes( $custom );
			} else {
				$ads .= '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( wp_get_attachment_url( $img ) ) . '" alt="' . esc_html__( 'Advertisement', 'truereview' ) . '" /></a>';
			}
		$ads .= '</div>';
	}

	// Display the ads before content
	if ( ! empty( $ads ) && is_single() ) {
		$content = $ads . $content;
	} else {
		$content;
	}

	return $content;

}
endif;
add_filter( 'the_content', 'truereview_post_ads_before', 20 );

if ( ! function_exists( 'truereview_post_ads_after' ) ) :
/**
 * Single post advertisement.
 * After content.
 *
 * @since  1.0.0
 */
function truereview_post_ads_after( $content ) {

	// Set up empty variable
	$ads = '';

	// Get the ads data set in customizer
	$img    = get_theme_mod( 'truereview-post-ads-image-after' );
	$url    = get_theme_mod( 'truereview-post-ads-url-after' );
	$custom = get_theme_mod( 'truereview-post-ads-custom-after' );
	$pos    = get_theme_mod( 'truereview-post-ads-position-after' );

	// Set up our ads.
	if ( $img || $url || $custom ) {
		$ads = '<div class="post-ads-after post-ads ' . esc_attr( $pos ) . '-position' . '">';
			if ( $custom ) {
				$ads .= stripslashes( $custom );
			} else {
				$ads .= '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( wp_get_attachment_url( $img ) ) . '" alt="' . esc_html__( 'Advertisement', 'truereview' ) . '" /></a>';
			}
		$ads .= '</div>';
	}

	// Display the ads before content
	if ( ! empty( $ads ) && is_single() ) {
		$content = $content . $ads;
	} else {
		$content;
	}

	return $content;

}
endif;
add_filter( 'the_content', 'truereview_post_ads_after', 20 );

if ( ! function_exists( 'truereview_post_ads_after_paragraph' ) ) :
/**
 * Single post advertisement.
 * After x paragraph.
 *
 * @since  1.0.0
 */
function truereview_post_ads_after_paragraph( $content ) {

	// Set up empty variable
	$ads = '';

	// Get the ads data set in customizer
	$img    = get_theme_mod( 'truereview-post-ads-image-after-paragraph' );
	$url    = get_theme_mod( 'truereview-post-ads-url-after-paragraph' );
	$custom = get_theme_mod( 'truereview-post-ads-custom-after-paragraph' );
	$pos    = get_theme_mod( 'truereview-post-ads-position-after-paragraph' );
	$par    = get_theme_mod( 'truereview-post-ads-paragraph-after-paragraph' );

	// Set up our ads.
	if ( $img || $url || $custom ) {
		$ads = '<div class="post-ads-after-paragraph post-ads ' . esc_attr( $pos ) . '-position' . '">';
			if ( $custom ) {
				$ads .= stripslashes( $custom );
			} else {
				$ads .= '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( wp_get_attachment_url( $img ) ) . '" alt="' . esc_html__( 'Advertisement', 'truereview' ) . '" /></a>';
			}
		$ads .= '</div>';
	}

	// Display the ads after x pargraph
	if ( ! empty( $ads ) && is_single() ) {
		return truereview_insert_after_paragraph( $ads, absint( $par ), $content );
	}

	return $content;

}
endif;
add_filter( 'the_content', 'truereview_post_ads_after_paragraph', 20 );

/**
 * Insert after paragraph function
 *
 * @since  1.0.0
 */
function truereview_insert_after_paragraph( $insertion, $paragraph_id, $content ) {
	$closing_p = '</p>';
	$paragraphs = explode( $closing_p, $content );
	foreach ($paragraphs as $index => $paragraph) {

		if ( trim( $paragraph ) ) {
			$paragraphs[$index] .= $closing_p;
		}

		if ( $paragraph_id == $index + 1 ) {
			$paragraphs[$index] .= $insertion;
		}
	}

	return implode( '', $paragraphs );
}

if ( ! function_exists( 'truereview_footer_ads' ) ) :
/**
 * Prints the advertisement data set in customizer.
 *
 * @since  1.0.0
 */
function truereview_footer_ads() {

	// Get the ads data set in customizer
	$img    = get_theme_mod( 'truereview-footer-ads-image' );
	$url    = get_theme_mod( 'truereview-footer-ads-url' );
	$custom = get_theme_mod( 'truereview-footer-ads-custom' );

	// Display the data
	if ( $img || $url || $custom ) {
		echo '<div class="footer-ads">';
			echo '<div class="container">';
				if ( $custom ) {
					echo stripslashes( $custom );
				} else {
					echo '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( wp_get_attachment_url( $img ) ) . '" alt="' . esc_html__( 'Advertisement', 'truereview' ) . '" /></a>';
				}
			echo '</div>';
		echo '</div>';
	}

}
endif;

/**
 * Retrieve tags list.
 */
function truereview_tags_list() {

	// Set up empty array.
	$tags = array();

	// Retrieve available tags.
	$tags_obj = get_tags();

	// Set default/empty tag.
	$tags[''] = esc_html__( 'Select a tag &hellip;', 'truereview' );

	// Display the tags.
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_attr( $tag->name );
	}

	return $tags;

}

/**
 * Sanitize the checkbox.
 *
 * @param boolean $input.
 * @return boolean (true|false).
 */
function truereview_sanitize_checkbox( $input ) {
	if ( 1 == $input ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Sanitize the Footer Credits
 */
function truereview_sanitize_textarea( $text ) {
	if ( current_user_can( 'unfiltered_html' ) ) {
		$text = $text;
	} else {
		$text = wp_kses_post( $text );
	}
	return $text;
}

/**
 * Sanitize the post date style value.
 */
function truereview_sanitize_post_date_style( $style ) {
	if ( ! in_array( $style, array( 'absolute', 'relative' ) ) ) {
		$style = 'absolute';
	}
	return $style;
}

/**
 * Sanitize the posts order value.
 */
function truereview_sanitize_orderby( $order ) {
	if ( ! in_array( $order, array( 'date', 'rand' ) ) ) {
		$order = 'date';
	}
	return $order;
}

/**
 * Sanitize the color value.
 */
function velove_sanitize_predefined_colors( $color ) {
	if ( ! in_array( $color, array( 'default', 'red', 'blue', 'indigo', 'cyan', 'magenta' ) ) ) {
		$color = 'default';
	}
	return $color;
}

/**
 * Sanitize the position value.
 */
function truereview_sanitize_ads_position( $position ) {
	if ( ! in_array( $position, array( 'default', 'center', 'right', 'f-left', 'f-right' ) ) ) {
		$position = 'default';
	}
	return $position;
}

/**
 * Sanitize the position value.
 */
function truereview_sanitize_post_ads_after_content( $position ) {
	if ( ! in_array( $position, array( 'default', 'center', 'right' ) ) ) {
		$position = 'default';
	}
	return $position;
}

/**
 * Sanitize the position value.
 */
function truereview_sanitize_post_ads_paragraph( $position ) {
	if ( ! in_array( $position, array( '1', '2', '3', '4', '5' ) ) ) {
		$position = '1';
	}
	return $position;
}
